@@ -30,16 +30,18 @@
 #include <config.h>
 
 #include "rcsid.h"
-RCSID (PKG_VER "$Id: chpasswd.c,v 1.14 2002/01/05 15:41:43 kloczek Exp $")
+RCSID (PKG_VER "$Id: chpasswd.c,v 1.22 2004/12/10 00:27:55 kloczek Exp $")
 #include <stdio.h>
 #include "prototypes.h"
 #include "defines.h"
 #include <pwd.h>
 #include <fcntl.h>
+#include <getopt.h>
 #include "pwio.h"
 #ifdef	SHADOWPWD
 #include "shadowio.h"
 #endif
+#include "nscd.h"
 #ifdef USE_PAM
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
@@ -47,6 +49,7 @@ RCSID (PKG_VER "$Id: chpasswd.c,v 1.14 2002/01/05 15:41:43 kloczek Exp $")
 #endif				/* USE_PAM */
 static char *Prog;
 static int eflg = 0;
+static int md5flg = 0;
 
 #ifdef SHADOWPWD
 static int is_shadow_pwd;
@@ -63,7 +66,13 @@ static void usage (void);
 
 static void usage (void)
 {
-	fprintf (stderr, _("usage: %s [-e]\n"), Prog);
+	fprintf (stderr, _("Usage: chpasswd [options]\n"
+			   "\n"
+			   "Options:\n"
+			   "  -e, --encrypted	supplied passwords are encrypted\n"
+			   "  -h, --help		display this help message and exit\n"
+			   "  -m, --md5		use MD5 encryption instead DES when the supplied\n"
+			   "			passwords are not encrypted\n"));
 	exit (1);
 }
 
@@ -87,10 +96,6 @@ int main (int argc, char **argv)
 #endif
 	const struct passwd *pw;
 	struct passwd newpw;
-
-#ifdef ATT_AGE
-	char newage[5];
-#endif
 	int errors = 0;
 	int line = 0;
 	long now = time ((long *) 0) / (24L * 3600L);
@@ -108,6 +113,39 @@ int main (int argc, char **argv)
 	bindtextdomain (PACKAGE, LOCALEDIR);
 	textdomain (PACKAGE);
 
+	{
+		int option_index = 0;
+		int c;
+		static struct option long_options[] = {
+			{"encrypted", no_argument, NULL, 'e'},
+			{"help", no_argument, NULL, 'h'},
+			{"md5", no_argument, NULL, 'm'},
+			{NULL, 0, NULL, '\0'}
+		};
+
+		while ((c =
+			getopt_long (argc, argv, "ehm", long_options,
+				     &option_index)) != -1) {
+			switch (c) {
+			case 'e':
+				eflg = 1;
+				break;
+			case 'h':
+				usage ();
+				break;
+			case 'm':
+				md5flg = 1;
+				break;
+			case 0:
+				/* long option */
+				break;
+			default:
+				usage ();
+				break;
+			}
+		}
+	}
+
 #ifdef USE_PAM
 	retval = PAM_SUCCESS;
 
@@ -118,7 +156,7 @@ int main (int argc, char **argv)
 
 	if (retval == PAM_SUCCESS) {
 		retval =
-		    pam_start ("shadow", pampw->pw_name, &conv, &pamh);
+		    pam_start ("chpasswd", pampw->pw_name, &conv, &pamh);
 	}
 
 	if (retval == PAM_SUCCESS) {
@@ -142,12 +180,6 @@ int main (int argc, char **argv)
 	}
 #endif				/* USE_PAM */
 
-	/* XXX - use getopt() */
-	if (!(argc == 1 || (argc == 2 && !strcmp (argv[1], "-e"))))
-		usage ();
-	if (argc == 2)
-		eflg = 1;
-
 	/*
 	 * Lock the password file and open it for reading. This will bring
 	 * all of the entries into memory where they may be updated.
@@ -223,8 +255,16 @@ int main (int argc, char **argv)
 			continue;
 		}
 		newpwd = cp;
-		if (!eflg)
-			cp = pw_encrypt (newpwd, crypt_make_salt ());
+		if (!eflg) {
+			if (md5flg) {
+				char salt[12] = "$1$";
+
+				strcat (salt, crypt_make_salt ());
+				cp = pw_encrypt (newpwd, salt);
+			} else
+				cp = pw_encrypt (newpwd,
+						 crypt_make_salt ());
+		}
 
 		/*
 		 * Get the password file entry for this user. The user must
@@ -262,13 +302,6 @@ int main (int argc, char **argv)
 		{
 			newpw = *pw;
 			newpw.pw_passwd = cp;
-#ifdef	ATT_AGE
-			if (newpw.pw_age[0]) {
-				strcpy (newage, newpw.pw_age);
-				strcpy (newage + 2, l64a (now / 7));
-				newpw.pw_age = newage;
-			}
-#endif
 		}
 
 		/* 
@@ -329,6 +362,9 @@ int main (int argc, char **argv)
 			 Prog);
 		exit (1);
 	}
+
+	nscd_flush_cache ("passwd");
+
 	pw_unlock ();
 
 #ifdef USE_PAM
